summaryrefslogtreecommitdiff
path: root/src/keyboard.c
diff options
context:
space:
mode:
authorEli Zaretskii <eliz@gnu.org>2022-08-13 18:52:46 +0300
committerEli Zaretskii <eliz@gnu.org>2022-08-13 18:52:46 +0300
commita1cf3b96f84794b708a9d80281d4e9deadfb610c (patch)
tree1ae3360397c9be608b3133e4ad7d8056d72cfba9 /src/keyboard.c
parentf289a17c068e5486f6d8fa695b4c36bcb9978996 (diff)
downloademacs-a1cf3b96f84794b708a9d80281d4e9deadfb610c.tar.gz
; Fix documentation of 'deactivate-mark'
* src/keyboard.c (syms_of_keyboard): * etc/NEWS: Fix the documentation of 'deactivate-mark' and its new value 'dont-save'. (Bug#57147)
Diffstat (limited to 'src/keyboard.c')
-rw-r--r--src/keyboard.c11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/keyboard.c b/src/keyboard.c
index 05c68ea7fbc..8a2b7d58c4b 100644
--- a/src/keyboard.c
+++ b/src/keyboard.c
@@ -12650,14 +12650,17 @@ cancels any modification. */);
DEFSYM (Qdeactivate_mark, "deactivate-mark");
DEFVAR_LISP ("deactivate-mark", Vdeactivate_mark,
- doc: /* If an editing command sets this to t, deactivate the mark afterward.
+ doc: /* Whether to deactivate the mark after an editing command.
The command loop sets this to nil before each command,
and tests the value when the command returns.
-Buffer modification stores t in this variable.
+If an editing command sets this non-nil, deactivate the mark after
+the command returns.
+
+Buffer modifications store t in this variable.
By default, deactivating the mark will save the contents of the region
-according to `select-active-regions'. If this is set to the symbol
-`dont-save', the region will not be saved.*/);
+according to `select-active-regions', unless this is set to the symbol
+`dont-save'. */);
Vdeactivate_mark = Qnil;
Fmake_variable_buffer_local (Qdeactivate_mark);